![CI](https://github.com/rishitgoel123/SentinelMesh/actions/workflows/ci.yml/badge.svg)
![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)
![Python](https://img.shields.io/badge/python-3.7%2B-blue)